/* Copyright Airship and Contributors */

#import <Foundation/Foundation.h>
#import "UAAPIClient.h"

@class UARuntimeConfig;

NS_ASSUME_NONNULL_BEGIN

/**
 * Represents possible named user API client errors.
 */
typedef NS_ENUM(NSInteger, UANamedUserAPIClientError) {
    /**
     * Indicates an unsuccessful client status.
     */
    UANamedUserAPIClientErrorUnsuccessfulStatus
};

/**
 * The domain for NSErrors generated by the named user client.
 */
extern NSString * const UANamedUserAPIClientErrorDomain;

/**
 * A high level abstraction for performing Named User API association and disassociation.
 */
@interface UANamedUserAPIClient : UAAPIClient

///---------------------------------------------------------------------------------------
/// @name Named User Internal Methods
///---------------------------------------------------------------------------------------

/**
 * Factory method to create a UANamedUserAPIClient.
 * @param config The Airship config.
 * @return UANamedUserAPIClient instance.
 */
+ (instancetype)clientWithConfig:(UARuntimeConfig *)config;

/**
 * Factory method to create a UANamedUserAPIClient.
 * @param config The Airship config.
 * @param session the request session.
 * @return UANamedUserAPIClient instance.
 */
+ (instancetype)clientWithConfig:(UARuntimeConfig *)config session:(UARequestSession *)session;

/**
 * Associates the channel to the named user ID.
 *
 * @param identifier The named user ID string.
 * @param channelID The channel ID string.
 * @param completionHandler The completion handler.
 */
- (void)associate:(NSString *)identifier
        channelID:(NSString *)channelID
completionHandler:(void (^)(NSError * _Nullable))completionHandler;

/**
 * Disassociate the channel from the named user ID.
 *
 * @param channelID The channel ID string.
 * @param completionHandler The completion handler.
 */
- (void)disassociate:(NSString *)channelID
   completionHandler:(void (^)(NSError * _Nullable))completionHandler;

@end

NS_ASSUME_NONNULL_END
